@@ -227,6 +227,13 @@ class REST(object):
         method = 'POST'
         return self.request(path, method, call_params)
 
+    def play_stop(self, call_params):
+        """REST PlayStop on a Call Helper
+        """
+        path = '/' + self.api_version + '/PlayStop/'
+        method = 'POST'
+        return self.request(path, method, call_params)
+
     def schedule_play(self, call_params):
         """REST Schedule playing something on a call Helper
         """
@@ -241,6 +248,20 @@ class REST(object):
         method = 'POST'
         return self.request(path, method, call_params)
 
+    def sound_touch(self, call_params):
+        """REST Add soundtouch audio effects to a Call
+        """
+        path = '/' + self.api_version + '/SoundTouch/'
+        method = 'POST'
+        return self.request(path, method, call_params)
+
+    def sound_touch_stop(self, call_params):
+        """REST Remove soundtouch audio effects on a Call
+        """
+        path = '/' + self.api_version + '/SoundTouchStop/'
+        method = 'POST'
+        return self.request(path, method, call_params)
+
     def conference_unmute(self, call_params):
         """REST Conference Unmute helper
         """
@@ -416,6 +437,9 @@ class Element(object):
     def addRedirect(self, url=None, **kwargs):
         return self.append(Redirect(url, **kwargs))
 
+    def addSIPTransfer(self, url=None, **kwargs):
+        return self.append(SIPTransfer(url, **kwargs))
+
     def addHangup(self, **kwargs):
         return self.append(Hangup(**kwargs))
 
@@ -451,7 +475,8 @@ class Response(Element):
     def __init__(self):
         Element.__init__(self)
         self.nestables = ('Speak', 'Play', 'GetDigits', 'Record', 'Dial',
-            'Redirect', 'Wait', 'Hangup', 'PreAnswer', 'Conference', 'GetSpeech')
+            'Redirect', 'Wait', 'Hangup', 'PreAnswer', 'Conference', 'GetSpeech',
+            'SIPTransfer')
 
 class Speak(Element):
     """Speak text
@@ -484,12 +509,8 @@ class Wait(Element):
     """Wait for some time to further process the call
 
     length: length of wait time in seconds
-    transferEnabled: if set to True allows the call to be transferred
-        via REST API even while in waiting state.
-        By default this is set to False, and in this case
-        transfer will only happen once wait finishes.
     """
-    VALID_ATTRS = ('length', 'transferEnabled')
+    VALID_ATTRS = ('length')
     def __init__(self, **kwargs):
         Element.__init__(self, **kwargs)
 
@@ -505,6 +526,17 @@ class Redirect(Element):
         Element.__init__(self, **kwargs)
         self.body = url
 
+class SIPTransfer(Element):
+    """SIPTransfer
+
+    url: sip uris 
+    """
+    VALID_ATTRS = ()
+
+    def __init__(self, url=None, **kwargs):
+        Element.__init__(self, **kwargs)
+        self.body = url
+
 class Hangup(Element):
     """Hangup the call
     """
@@ -577,8 +609,10 @@ class Conference(Element):
           (default false)
     startConferenceOnEnter: the conference start when this member joins
           (default true)
-    endConferenceOnExit: close conference after this member leaves
-          (default false)
+    endConferenceOnExit: close conference after all members
+            with this attribute set to 'true' leave. (default false)
+    stayAlone: if 'false' and member is alone, conference is closed and member kicked out
+          (default true)
     maxMembers: max members in conference
           (0 for max : 200)
     enterSound: sound to play when a member enters
@@ -614,7 +648,7 @@ class Conference(Element):
                    'endConferenceOnExit','waitSound','enterSound', 'exitSound',
                    'timeLimit', 'hangupOnStar', 'maxMembers', 'recordFilePath',
                    'recordFileFormat', 'recordFileName', 'action', 'method',
-                   'digitsMatch', 'callbackUrl', 'callbackMethod')
+                   'digitsMatch', 'callbackUrl', 'callbackMethod', 'stayAlone')
 
     def __init__(self, room, **kwargs):
         Element.__init__(self, **kwargs)
@@ -675,7 +709,7 @@ class PreAnswer(Element):
 
     def __init__(self, **kwargs):
         Element.__init__(self, **kwargs)
-        self.nestables = ('Play', 'Speak', 'GetDigits', 'Wait', 'GetSpeech')
+        self.nestables = ('Play', 'Speak', 'GetDigits', 'Wait', 'GetSpeech', 'Redirect', 'SIPTransfer')
 
 
 # Plivo Utility function and Request Validation
